@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2002 Bill Wilson
+|  Copyright (C) 1999-2003 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -50,6 +50,9 @@
 #define SIGTSTP SIGTERM
 #define ioctl ioctlsocket
 #include "../src/win32.h"
+#if defined(_WINDOWS)
+#include "resource.h"
+#endif
 #endif
 
 #include <sys/stat.h>
@@ -132,7 +135,7 @@ extern int	errno;
 */
 #define GKRELLMD_VERSION_MAJOR   2
 #define GKRELLMD_VERSION_MINOR   1
-#define GKRELLMD_VERSION_REV     4
+#define GKRELLMD_VERSION_REV     5
 #define GKRELLMD_EXTRAVERSION    ""
 
 #define GKRELLMD_CONFIG     "gkrellmd.conf"
