@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2002 Bill Wilson
+|  Copyright (C) 1999-2003 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -71,7 +71,9 @@ struct	GkrellmConfig
 
 	gboolean	force_host_config;
 	gboolean	found_host_config;
-	gboolean	no_config;
+	gboolean	no_config,
+				allow_multiple_instances,
+				allow_multiple_instances_real;
 
 	gint		frame_left_width,
 				frame_right_width,
@@ -111,6 +113,8 @@ struct	GkrellmConfig
 				decorated,
 				command_line_decorated;	/* Will override decorated */
 
+	gboolean	set_wm_state_hack;	/* Temporary aid for net_wm_state bugs */
+
 	gboolean	enable_hostname,		/* No separate hostname config. */
 				hostname_short,
 				enable_system_name;
