@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2002 Bill Wilson
+|  Copyright (C) 1999-2003 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -1496,6 +1496,23 @@ cb_size_allocate(GtkWidget *w, GtkAllocation *size, gpointer data)
 	return FALSE;
 	}
 
+static gboolean
+cb_map_event(GtkWidget *widget, GdkEvent *event, gpointer data)
+	{
+	if (_GK.set_wm_state_hack)	/* Temporary option */
+		{
+		if (_GK.state_skip_pager)
+			gkrellm_winop_state_skip_pager(TRUE);
+		if (_GK.state_skip_taskbar)
+			gkrellm_winop_state_skip_taskbar(TRUE);
+		if (_GK.state_above)
+			gkrellm_winop_state_above(TRUE);
+		else if (_GK.state_above)
+			gkrellm_winop_state_below(TRUE);
+		}
+	return FALSE;
+	}
+
 static gboolean
 cb_configure_notify(GtkWidget *widget, GdkEventConfigure *ev, gpointer data)
 	{
@@ -1960,6 +1977,10 @@ main(gint argc, gchar **argv)
 
 	load_user_config(FALSE);		
 	decorated = (_GK.command_line_decorated || _GK.decorated);
+	if (_GK.command_line_plugin || _GK.command_line_theme)
+		_GK.allow_multiple_instances_real = TRUE;
+	_GK.allow_multiple_instances_real |= _GK.allow_multiple_instances;
+
 	create_widget_tree();
 	top_window = gtree.window;
 
@@ -1976,6 +1997,8 @@ main(gint argc, gchar **argv)
 				G_CALLBACK(cb_destroy_event), NULL);
 	g_signal_connect(G_OBJECT(gtree.window), "configure_event",
 				G_CALLBACK(cb_configure_notify), NULL);
+	g_signal_connect(G_OBJECT(gtree.window), "map_event",
+				G_CALLBACK(cb_map_event), NULL);
 	g_signal_connect(G_OBJECT(gtree.window), "size_allocate",
 				G_CALLBACK(cb_size_allocate), NULL);
 	g_signal_connect(G_OBJECT(gtree.window), "client_event",
