@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2002 Bill Wilson
+|  Copyright (C) 1999-2003 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -1182,6 +1182,8 @@ gkrellm_sys_battery_init(void)
 /* ===================================================================== */
 /* Sensor monitor interface */
 
+#if defined(__i386__)
+
 typedef struct
 	{
 	gchar	*name;
@@ -1207,11 +1209,12 @@ static VoltDefault	voltdefault0[] =
 	{ "-5V",	-1.667, 0, NULL }		/* in6 -(100/60)*@		*/
 	};
 
-#if defined(__i386__)
 #include <dirent.h>
 #include <osreldate.h>
 #include <machine/cpufunc.h>
-#if __FreeBSD_version >= 300000
+#if __FreeBSD_version >= 500042
+#include <dev/smbus/smb.h>
+#elif __FreeBSD_version >= 300000
 #include <machine/smb.h>
 #endif
 
@@ -1442,4 +1445,34 @@ gkrellm_sys_sensors_init(void)
 	return (found_sensors | found_acpi_sensors);
 	}
 
+#else
+
+gboolean
+gkrellm_sys_sensors_get_temperature(gchar *path, gint id,
+		gint iodev, gint interface, gfloat *temp)
+
+	{
+	return FALSE;
+	}
+
+gboolean
+gkrellm_sys_sensors_get_fan(gchar *path, gint id,
+		gint iodev, gint interface, gfloat *fan)
+	{
+	return FALSE;
+	}
+
+gboolean
+gkrellm_sys_sensors_get_voltage(gchar *path, gint id,
+		gint iodev, gint interface, gfloat *volt)
+	{
+	return FALSE;
+	}
+
+gboolean
+gkrellm_sys_sensors_init(void)
+	{
+	return FALSE;
+	}
+
 #endif
