@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2002 Bill Wilson
+|  Copyright (C) 1999-2003 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -348,7 +348,31 @@ gkrellm_sys_disk_name_from_device(gint device_number, gint unit_number,
 gint
 gkrellm_sys_disk_order_from_name(gchar *name)
 	{
-	return 0;	/* Disk by name not implemented in Linux */
+	struct _disk_name_map	*dm, *dm_next;
+	gint		i, len, table_size;
+	gchar		suffix;
+
+	table_size = sizeof(disk_name_map) / sizeof(struct _disk_name_map);
+	for (i = 0; i < table_size; ++i)
+		{
+		dm = &disk_name_map[i];
+		len = strlen(dm->name);
+		if (strncmp(dm->name, name, strlen(dm->name)))
+			continue;
+		suffix = name[len];
+		if (i < table_size - 1)
+			{
+			dm_next = &disk_name_map[i + 1];
+			if (   !strcmp(dm_next->name, dm->name)
+				&& dm_next->suffix_base <= suffix
+			   )
+				continue;
+			}
+		break;
+		}
+	if (i >= table_size)
+		i = -1;
+	return i;
 	}
 
 
