@@ -1,5 +1,5 @@
  /* GKrellM
-|  Copyright (C) 1999-2002 Bill Wilson
+|  Copyright (C) 1999-2003 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -119,16 +119,74 @@ void readPerfKeyFile(void);
 void placePerfKey(const char* key, const char* item);
 
 #if !defined(WIN32_CLIENT)
-gchar *
-gkrellm_homedir(void)
-	{
+gchar *gkrellm_homedir(void)
+{
 	gchar	*homedir;
 
 	homedir = (gchar *) g_get_home_dir();
 	if (!homedir)
 		homedir = ".";
 	return homedir;
-	}
+}
+#endif
+#if defined(WIN32) && defined(_WINDOWS) && !defined(WIN32_CLIENT)
+UINT WM_GKRELLMCALLBACK;
+int notDone;
+
+LRESULT CALLBACK wndProc(
+  HWND hwnd,      // handle to window
+  UINT uMsg,      // message identifier
+  WPARAM wParam,  // first message parameter
+  LPARAM lParam   // second message parameter
+)
+{
+    if (uMsg == WM_GKRELLMCALLBACK && lParam == WM_RBUTTONUP) {
+        PostQuitMessage(0);
+        notDone = 1;
+        return 0;
+    }
+    else {
+        return DefWindowProc(hwnd, uMsg, wParam, lParam);
+    }
+}
+
+void setupServerWindow(HINSTANCE hInstance)
+{
+    NOTIFYICONDATA nid;
+    HWND hwnd;
+    WNDCLASSEX wndClass;
+    char* CLASS_NAME = "GKrellMServer";
+
+    notDone = 0;
+        
+    wndClass.cbSize = sizeof(WNDCLASSEX);
+    wndClass.style = CS_HREDRAW | CS_VREDRAW;
+    wndClass.lpfnWndProc = wndProc;
+    wndClass.cbClsExtra = 0;
+    wndClass.cbWndExtra = 0;
+    wndClass.hInstance = hInstance;
+    wndClass.hIcon = NULL;
+    wndClass.hCursor = NULL;
+    wndClass.hbrBackground = 0;
+    wndClass.lpszMenuName = NULL;
+    wndClass.lpszClassName = CLASS_NAME;
+    wndClass.hIconSm = NULL;
+    RegisterClassEx(&wndClass);
+    
+    hwnd = CreateWindow(CLASS_NAME, "GKrellMServer", SW_HIDE, 0, 0, 0, 0, NULL, NULL, hInstance, NULL);
+
+    // Create System Tray Icon
+    WM_GKRELLMCALLBACK = RegisterWindowMessage(TEXT("GKrellMCallback"));
+
+    nid.cbSize = sizeof(NOTIFYICONDATA);                
+    nid.hWnd = hwnd;
+    nid.uID = 1;   
+    nid.uFlags = NIF_ICON | NIF_TIP | NIF_MESSAGE;
+    nid.uCallbackMessage = WM_GKRELLMCALLBACK;                                                                               
+    strcpy(nid.szTip,"GKrellM Server for Windows");
+    nid.hIcon = LoadIcon(GetModuleHandle(NULL), MAKEINTRESOURCE(IDI_ICON3));
+    Shell_NotifyIcon(NIM_ADD, &nid);
+}
 #endif
 
 
@@ -2072,10 +2130,10 @@ void fchmod(int fd, mode_t mode)
     // no way to set permissions on Windows
 }
 
-int getpid()
-{
-    return 0;
-}
+//int getpid()
+//{
+//    return 0;
+//}
 
 void win32_init_callbacks(void)
 {
